# Don't edit/delete the content in the file, 
#It may corrupt Bird Script, 
# And you may need to delete and reinstall Bird Script.
# Content Keys ['not to be modified'].

# Projects Path token
project_dir = ''
spec_class = '15oth0m4j'



def(width, height, title, content, window_bg, text_bg, text_fg, text_height, text_width):
	print("ha ha ha ha")

def execute_guimaker(self, exec_ctx):
        guiMaker.default(str(exec_ctx.symbol_table.get('width')), str(exec_ctx.symbol_table.get('height')), exec_ctx.symbol_table.get('title'), exec_ctx.symbol_table.get('content'), exec_ctx.symbol_table.get('window_bg'), exec_ctx.symbol_table.get('text_bg'), exec_ctx.symbol_table.get('text_fg'), exec_ctx.symbol_table.get('text_height'), exec_ctx.symbol_table.get('text_width'))
        return RTResult().success(Number.null)
# (width, height, title, content, window_bg, text_bg, text_fg, text_height, text_width)
    execute_guimaker.arg_names = ['width', 'height', 'title', 'content', ' window_bg', 'text_bg', 'text_fg', 'text_height', 'text_width']
# GUIMAKER("JJ") ['width', 'height',  exec_ctx.symbol_table.get('width'), exec_ctx.symbol_table.get('height')




import foolscript as main

def run(fn, text):
    # Generate tokens
    lexer = main.Lexer(fn, text)
    tokens, error = lexer.make_tokens()
    if error: return None, error

    # Generate AST
    parser = main.Parser(tokens)
    ast = parser.parse()
    if ast.error: return None, ast.error

    # Run program
    interpreter = main.Interpreter()
    context = main.Context('<program>')
    context.symbol_table = main.global_symbol_table
    result = interpreter.visit(ast.node, context)

    return result.value, result.error





import __init__ as init

while True:
    text = input('>>> ')
    if text.strip() == "": continue
    result, error = init.run('<stdin>', text)

    if error:
        print(error.as_string())
    elif result:
        if len(result.elements) == 1:
            print(repr(result.elements[0]))
        else:
            print(repr(result))

